couchdb.client.Row

Package couchdb :: Module client :: Class Row |

# Class Row

    object --+
             |
          dict --+
                 |
                Row

Representation of a row as returned by database views.

Instance Methods
__repr__(self) repr(x) |
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
| id The associated Document ID if it exists.
| key The associated key.
| value The associated value.
| doc The associated document for the row.
Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

Property Details

### id The associated Document ID if it exists. Returns `None` when it doesn't (reduce results). Get Method: unreachable.id(self) - The associated Document ID if it exists.

### key The associated key. Get Method: unreachable.key(self) - The associated key.

### value The associated value. Get Method: unreachable.value(self) - The associated value.

### doc The associated document for the row. This is only present when the view was accessed with `include_docs=True` as a query parameter, otherwise this property will be `None`. Get Method: unreachable.doc(self) - The associated document for the row.